==> blesta-5.10.2.zip: blesta/plugins/order/language/sv_se/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.sv_se
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.index.field_recovery_email'] = 'E-post för återställning (valfritt)';
$lang['Signup.!error.email.blacklist'] = 'Din beställning kan inte behandlas för närvarande.';
$lang['Signup.index.signup_btn'] = 'Skapa konto';
$lang['Signup.index.continue_btn'] = 'Fortsätt till kassan';
$lang['Signup.index.login_btn'] = 'Logga in';
$lang['Signup.index.field_receive_email_marketing'] = 'Jag vill få e-post om nya produkter, tjänster och erbjudanden.';
$lang['Signup.index.field_confirmpassword'] = 'Bekräfta lösenord';
$lang['Signup.index.field_newpassword'] = 'Lösenord';
$lang['Signup.index.field_password'] = 'Lösenord';
$lang['Signup.index.field_username'] = 'Användarnamn';
$lang['Signup.index.field_action_signup'] = 'Skapa ett konto';
$lang['Signup.index.field_action_login'] = 'Logga in';
$lang['Signup.index.field_action_continue'] = 'Fortsätt som %1$s %2$s';
$lang['Signup.index.field_username_type_username'] = 'Ange ett användarnamn';
$lang['Signup.index.field_username_type_email'] = 'Använd e-post som användarnamn';
$lang['Signup.index.field_email'] = 'E-post';
$lang['Signup.index.field_fax'] = 'Fax';
$lang['Signup.index.field_phone'] = 'Telefon';
$lang['Signup.index.field_title'] = 'Titel';
$lang['Signup.index.field_country'] = 'Land';
$lang['Signup.index.field_zip'] = 'Postnummer';
$lang['Signup.index.field_state'] = 'Stat/Provins';
$lang['Signup.index.field_city'] = 'Stad';
$lang['Signup.index.field_address2'] = 'Adress 2';
$lang['Signup.index.field_address1'] = 'Adress 1';
$lang['Signup.index.field_company'] = 'Företag/Org.';
$lang['Signup.index.field_lastname'] = 'Efternamn';
$lang['Signup.index.field_firstname'] = 'Förnamn';
$lang['Signup.index.field_taxid'] = 'Skatte-ID/VATIN';
$lang['Signup.!notice.email_verification'] = 'Ett meddelande har skickats för att verifiera din e-postadress. Vänligen slutför verifieringen så snart som möjligt.';
$lang['Signup.!notice.force_email_usernames'] = 'Ditt användarnamn är detsamma som din e-postadress.';
$lang['Signup.!error.not_client_owner'] = 'Du måste vara inloggad som kundägare för att kunna fortsätta.';
$lang['Signup.!error.captcha.invalid'] = 'Den angivna captcha var ogiltig. Vänligen försök igen.';

==> blesta-5.11.4.zip: blesta/plugins/order/language/sv_se/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.sv_se
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.index.field_recovery_email'] = 'E-post för återställning (valfritt)';
$lang['Signup.!error.email.blacklist'] = 'Din beställning kan inte behandlas för närvarande.';
$lang['Signup.index.signup_btn'] = 'Skapa konto';
$lang['Signup.index.continue_btn'] = 'Fortsätt till kassan';
$lang['Signup.index.login_btn'] = 'Logga in';
$lang['Signup.index.field_receive_email_marketing'] = 'Jag vill få e-post om nya produkter, tjänster och erbjudanden.';
$lang['Signup.index.field_confirmpassword'] = 'Bekräfta lösenord';
$lang['Signup.index.field_newpassword'] = 'Lösenord';
$lang['Signup.index.field_password'] = 'Lösenord';
$lang['Signup.index.field_username'] = 'Användarnamn';
$lang['Signup.index.field_action_signup'] = 'Skapa ett konto';
$lang['Signup.index.field_action_login'] = 'Logga in';
$lang['Signup.index.field_action_continue'] = 'Fortsätt som %1$s %2$s';
$lang['Signup.index.field_username_type_username'] = 'Ange ett användarnamn';
$lang['Signup.index.field_username_type_email'] = 'Använd e-post som användarnamn';
$lang['Signup.index.field_email'] = 'E-post';
$lang['Signup.index.field_fax'] = 'Fax';
$lang['Signup.index.field_phone'] = 'Telefon';
$lang['Signup.index.field_title'] = 'Titel';
$lang['Signup.index.field_country'] = 'Land';
$lang['Signup.index.field_zip'] = 'Postnummer';
$lang['Signup.index.field_state'] = 'Stat/Provins';
$lang['Signup.index.field_city'] = 'Stad';
$lang['Signup.index.field_address2'] = 'Adress 2';
$lang['Signup.index.field_address1'] = 'Adress 1';
$lang['Signup.index.field_company'] = 'Företag/Org.';
$lang['Signup.index.field_lastname'] = 'Efternamn';
$lang['Signup.index.field_firstname'] = 'Förnamn';
$lang['Signup.index.field_taxid'] = 'Skatte-ID/VATIN';
$lang['Signup.!notice.email_verification'] = 'Ett meddelande har skickats för att verifiera din e-postadress. Vänligen slutför verifieringen så snart som möjligt.';
$lang['Signup.!notice.force_email_usernames'] = 'Ditt användarnamn är detsamma som din e-postadress.';
$lang['Signup.!error.not_client_owner'] = 'Du måste vara inloggad som kundägare för att kunna fortsätta.';
$lang['Signup.!error.captcha.invalid'] = 'Den angivna captcha var ogiltig. Vänligen försök igen.';
$lang['Signup.otp.field_submit'] = 'Logga in';
$lang['Signup.otp.field_otp'] = 'Lösenord för engångsbruk';
$lang['Signup.otp.login_heading'] = 'Logga in';
$lang['Signup.index.field_agree_tos'] = 'Jag har läst och godkänner de <a href="%1$s" target="_blank">allmänna villkoren</a>';
$lang['Signup.otp.description'] = 'Vänligen ange ditt engångslösenord.';
$lang['Signup.otp.page_title'] = 'Logga in';
$lang['Signup.!error.invalid_agree_tos'] = 'Du måste bekräfta att du samtycker till villkoren.';
